@@ -36,12 +36,16 @@ class NameErrorExtensionTest < Minitest::Test
     error.to_s
     assert_equal 1, error.to_s.scan("Did you mean?").count
   end
-end
 
-class DeprecatedIgnoreCallersTest < Minitest::Test
-  def test_ignore
-    assert_output nil, "IGNORED_CALLERS has been deprecated and has no effect.\n" do
-      DidYouMean::IGNORED_CALLERS << /( |`)do_not_correct_typo'/
-    end
+  def test_correctable_error_objects_are_dumpable
+   error = begin
+             File.open('./tmp/.keep').sizee
+           rescue NoMethodError => e
+             e
+           end
+
+   error.to_s
+
+   assert_equal "undefined method `sizee' for #<File:./tmp/.keep>", Marshal.load(Marshal.dump(error)).original_message
   end
 end
